@@ -8,10 +8,12 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 
+#undef ENABLE_PROFILER
 
 #undef GUPPI_MAJOR_VERSION
 #undef GUPPI_MINOR_VERSION
 #undef GUPPI_MICRO_VERSION
+#undef GUPPI_FROM_CVS
 
 #undef USING_OLD_FONT_API
 #undef HAVE_GUILE
